@@ -15,15 +15,13 @@ def merge(old_dir,new_dir):
             os.system('mkdir {dir}'.format(dir=new_child_dir))
         #列出文件夹下所有文件
         l = list(map(lambda x:x[0:x.index('.')],os.listdir(new_child_dir)))
-        print(l)
         for file in os.listdir(old_child_dir):
             #如果文件不存在
             file_name = file[0:file.index('.')]
             if(file_name not in l):
-                layout_file = new_res_dir + "/layout"+file
+                layout_file = new_res_dir + "/layout/"+file
                 if 'layout-' in dir and os.path.isfile(layout_file):
                     pass
                 else:
                     cp = 'cp {from_dir}/{file} {to_dir}'.format(from_dir=old_child_dir,file=file,to_dir=new_child_dir).replace("$", "\$")
                     os.system(cp)
-                    
\ No newline at end of file
